# Generated by Django 2.0.4 on 2018-06-05 16:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('storekit', '0003_auto_20171219_0021'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='purchase',
            name='response',
        ),
        migrations.DeleteModel(
            name='Purchase',
        ),
    ]
